# Motors for Motion Control Applications

Choosing the right motor is critical for the efficiency and productivity
of the motion control applications.
It can be difficult to choose between servo motors and stepper motors
as there are so many considerations:
cost, torque, efficiency, speed, circuitry and more.

## Differences in Servo Motors and Stepper Motors for Motion Control Applications:

- The main difference between these motors comes from the overall pole count.
  Stepper motors have a high pole count, usually between 50 and 100.
  Servo motors have a low pole count – between 4 and 12.

- This difference in pole count means that stepper motors move incrementally
  with a consistent pulse in a closed loop system.
  Servo motors require an encoder to adjust pulses for position control.

## Stepper Motors in Motion Control: Pros and Cons

Pros:

- Stepper motors, due to their high pole count,
  offer precision drive control for motion control applications.

- They have a high torque at low speeds,
  and they’re also relatively inexpensive and widely available.

Cons:

- At high-speeds, stepper motors lose nearly all of their torque,
  sometimes up to 80%.

- They produce high vibrations levels and are prone to resonance issues.

- Stepper motors also produce high amounts of heat,
  which can be an issue in certain applications.

## Servo Motors in Motion Control: Pros and Cons

Pros:

- The main benefit of servo motors
  is they provide high levels of torque at high speed –
  something stepper motors can’t do.

- They also operate at 80 – 90% efficiency.

- Servo motors can work in AC or DC drive,
  and do not suffer from vibration or resonance issues.

Cons:

- Servo motors are more expensive than stepper motors.
  Add in the cost of an encoder, and often a gearbox,
  and the whole system can become quite costly.

- The need for an encoder and gearbox makes the system more mechanically complex,
  leading to more frequent maintenance and higher costs.

## Key Questions of Stepper Motors

A stepper motor can be a good choice whenever controlled movement is required.
They can be used in applications
where we need to control rotation angle, speed, position and synchronism.
Because of the inherent advantages listed previously,
stepper motors have found their place in many different applications.
Some of these include printers, plotters, X-Y tables, laser cutters,
engraving machines, pick-place devices and so on.

### How to Choose Steppers Motors for DIY CNC machines?

Choosing a stepper very much depends on the type of machine we have
or are going to build and the material we are going to cut.
When selecting a stepper motor for our application,
there are several factors that need to be taken into consideration:

- How will the motor be coupled to the load?
- How fast does the load need to move or accelerate?
- How much torque is required to move the load?
- What degree of accuracy is required when positioning the load?

The most technical ways of choosing the stepper motors
are mentioned in [Motor Sizing](https://www.orientalmotor.com/technology/motor-sizing-calculations.html).
This repository contains the simplest way
to choose a stepper motor for the DIY CNC machines.
More details can be found in [Stepper Motors and Controllers](https://rckeith.co.uk/how-to-choose-steppers-motors-and-controllers-for-diy-cnc-machines/).
Let's start with understanding the **NEMA** standard.

#### Nema Standard

- NEMA (National Electrical Manufacturers Association)
  is a standard that defines the size of the faceplate of the motor.

- Two of the most popular sizes for DIY machines
  are NEMA17 (1.7 in x 1.7 in) and NEMA23 (2.3 in x 2.3 in).

### How to Understand the Stepper Motor Specifications?

#### 1) Rated Current

- This is the maximum current we may pass through both windings at the same time.

- The maximum current through one winding
  (which is what really matters when using microstepping)
  is rarely quoted and will be a little higher.

- However, even with one winding driven at the quoted rated current,
  the motor will get very hot.

- The usual practice is to set the motor current
  to no more than about 85% of the rated current.

- Therefore, to get maximum torque out of the stepper motors
  without overheating them, we should choose motors
  with a current rating no more than 25% higher
  than the recommended maximum stepper driver current.

#### 2) Torque Rating

- Stepper motors are rated by their holding torque
  in oz / in (ounces per inch) or N.m (Newton-metre), etc.

- Holding torque is the maximum torque that the motor can provide
  with both windings energized at full current before it starts jumping steps.

- **Example**: a NEMA23 might say 175 oz / in.
  So it can hold 175 ounces on an arm of 1 inch in length attached to the motor shaft.

- We also need to note how much current the motor will draw
  and the voltage it needs to work at.

- The holding torque with one winding energized at the rated current
  is about ***1 / sqrt(2)*** times that.

- The torque is proportional to current (except at very low currents),
  so for example, if we set the drivers to 85% of the motor rated current,
  then the maximum torque will be ***85% * 0.707 = 60%***
  of the specified holding torque.

#### 3) Unipolar / Bipolar

- Stepper motors can be bipolar or unipolar.
  This has to do with the way coils are connected.
  Nearly all motors for hobby CNC machines are sold as bipolar.

- A bipolar stepper motor has an onboard driver that uses an H bridge circuit
  to reverse the current flow through the phases.
  By energizing the phases while alternating the polarity,
  all the coils can be put to work turning the motor.

- In practical terms, this means that the coil windings are better utilized
  in a bipolar than a standard unipolar stepper motor
  (which only uses 50% of the wire coils at any one time),
  making bipolar stepper motors more powerful and efficient to run.

- For the same reason, bipolar motors have a high torque output.
  To learn more about the wiring, check this [Wiring Configurataion](https://blog.orientalmotor.com/wiring-basics-unipolar-vs-bipolar).

- However, the motors need more complex circuitry to switch the coils.
  This isn’t an issue because the driver modules do this for us.

#### 4) Step angle

- There are two common step angles:
  0.9 and 1.8 degrees per full step, corresponding to 400 and 200 steps/revolution.

- 0.9 deg motors have slightly lower holding torque
  than similar 1.8 deg motors from the same manufacturer.

